@@ -6,8 +6,9 @@ import inspect
 jsonpickle.set_encoder_options('simplejson', indent=4)
 jsonpickle.set_encoder_options('demjson', compactly=False)
 
-class Model:
-    pass
+class List:
+    def __init__(self, item_type):
+        self.item_type = item_type
 
 class Field:
     def __init__(self, field_type=None, default=None):
@@ -36,13 +37,15 @@ def get_field_value(field, field_meta, structure):
 
 def to_object(structure, obj_type=None):
     if obj_type:
-        obj = obj_type()
-        for field, field_meta in inspect.getmembers(obj):
-            if isinstance(field_meta, Field):
-                value = get_field_value(field, field_meta, structure)
-                setattr(obj, field, value)
-        return obj
-
+        if isinstance(obj_type, List):
+            return [to_object(item, obj_type.item_type) for item in structure]
+        else:
+            obj = obj_type()
+            for field, field_meta in inspect.getmembers(obj):
+                if isinstance(field_meta, Field):
+                    value = get_field_value(field, field_meta, structure)
+                    setattr(obj, field, value)
+            return obj
     else:
         if isinstance(structure, list):
             return [to_object(item) for item in structure]
